"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const winston_1 = require("winston");
const app_root_path_1 = __importDefault(require("app-root-path"));
const { combine, timestamp, label, printf } = winston_1.format;
const tagLen = 8;
const faceLen = 6;
const levelSign = {
    info: 'ℹ️',
    warning: '⚠️',
    error: '⛔️',
    debug: '☢️'
};
class ServiceLogger {
    constructor(serviceName, instanceName, path, face) {
        this.serviceName = 'undefined';
        this.instanceName = 'undefined';
        this.path = 'logs';
        this.face = '';
        this.logger = null;
        this.mode = "normal";
        if (serviceName.length <= tagLen) {
            this.serviceName = serviceName;
        }
        else {
            console.error(`Service name cannot be longer than ${tagLen} characters`);
            process.exit(1);
        }
        if (instanceName.length <= tagLen) {
            this.instanceName = instanceName;
        }
        else {
            console.error(`Instance name cannot be longer than ${tagLen} characters`);
            process.exit(1);
        }
        if (!face) { }
        else if (face.length > faceLen) {
            this.face = face;
        }
        else {
            console.error(`Face string cannot be longer than ${tagLen} characters`);
            process.exit(1);
        }
        this.path = path || this.path;
        const style = printf((info) => {
            const level = levelSign[info.level];
            const sern = this.serviceName.toUpperCase() + Array(tagLen + 1 - this.serviceName.length).join(' ');
            const insn = this.instanceName.toUpperCase() + Array(tagLen + 1 - this.instanceName.length).join(' ');
            const now = new Date();
            return `@${sern} #${insn} [${now.getHours()}:${now.getMinutes()}]  ${this.face} ${level}| ${info.message}`;
        });
        const options = {
            file: {
                filename: `${app_root_path_1.default}/${this.path}/${this.serviceName}.log`,
                handleExceptions: true,
                json: true,
                maxsize: 5242880,
                maxFiles: 1,
                colorize: false
            },
            console: {
                handleExceptions: true,
                json: false,
                colorize: true
            }
        };
        this.logger = winston_1.createLogger({
            format: combine(timestamp(), style),
            transports: [
                new winston_1.transports.File(options.file),
                new winston_1.transports.Console(options.console)
            ],
            exitOnError: false
        });
    }
    info(message) {
        if (this.logger != null)
            this.logger.info(message);
    }
    warn(message) {
        if (this.logger != null)
            this.logger.warn(message);
    }
    err(message) {
        if (this.logger != null)
            this.logger.error(message);
    }
    silent() {
        this.mode = 'silent';
    }
}
class LogManager {
    constructor(serviceName, path) {
        this.serviceName = serviceName;
        this.path = path || 'logs';
    }
    getLogger(instanceName) {
        return new ServiceLogger(this.serviceName, instanceName, this.path);
    }
}
exports.default = LogManager;
//# sourceMappingURL=index.js.map